==> cambridge-3.4.0.tar.gz: cambridge-3.4.0/cambridge/colorschemes/webster_color.py <==
bold = "bold"
italic = "italic"
accessory = "#4A7D95"


#####################
# dictionary-entry 
#####################

# --- entry-header-content --- #
eh_h1_word = "yellow"
eh_fg_entry_num = "#0A1B27"
eh_bg_entry_num = "#F4F4F4"
eh_entry_num = "{} on {}".format(eh_fg_entry_num, eh_bg_entry_num)
eh_word_type = "#4A7D95"
eh_word_syllables = "#757575"
eh_pron = "#4A7D95"

# --- verb tenses, noun plurals, adjective comparative forms --- #
wt = "#525A5B"

# --- other word forms --- #
wf = "#FFFFFF"
wf_type = "#4A7D95"

# --- transitive / intransitive --- #
tran = "#0074CC"

# --- one meaning of one entry --- #
meaning_num = "#4A7D95"
meaning_letter = "#4A7D95"
meaning_link = "#0074CC"
meaning_content = "#F4F4F4"
meaning_badge = "red"
meaning_sentence = "#757575"

# --- see also --- #
sa_title = "#FFFFFF"
sa_content = "#4A7D95"

wf = "#FFFFFF"
wf_type = "#4A7D95"


#####################
# phrases 
#####################
ph_title = "yellow"
ph_item = "#FFFFFF"


#####################
# synonyms 
#####################
syn_title = "yellow"
syn_item = "#0074CC"
syn_em = "yellow"
syn_label = "#0F3850"


#####################
# examples on the web 
#####################
eg_title = "yellow"
eg_sentence = "#757575"
eg_word = "yellow"


#####################
# related phrases 
#####################
rph_title = "yellow"
rph_item = "#0074CC"


#####################
# nearby entries 
#####################
nearby_title = "yellow"
nearby_em = "yellow"
nearby_word = "#757575"
nearby_item = "#0074CC"


#####################
# dict name
#####################
dict_name = "#757575"

==> cambridge-3.5.0.tar.gz: cambridge-3.5.0/cambridge/colorschemes/webster_color.py <==
bold = "bold"
italic = "italic"
accessory = "#4A7D95"
badge = "red"


#####################
# dictionary-entry 
#####################

# --- entry-header-content --- #
eh_h1_word = "yellow"
eh_fg_entry_num = "#0A1B27"
eh_bg_entry_num = "#F4F4F4"
eh_entry_num = "{} on {}".format(eh_fg_entry_num, eh_bg_entry_num)
eh_word_type = "#4A7D95"
eh_word_syllables = "#757575"
eh_pron = "#4A7D95"

# --- verb tenses, noun plurals, adjective comparative forms --- #
wt = "#525A5B"

# --- other word forms --- #
wf = "#FFFFFF"
wf_type = "#4A7D95"

# --- transitive / intransitive --- #
tran = "#0074CC"

# --- one meaning of one entry --- #
meaning_num = "#4A7D95"
meaning_letter = "#4A7D95"
meaning_link = "#0074CC"
meaning_content = "#F4F4F4"
meaning_badge = badge
meaning_sentence = "#757575"

# --- see also --- #
sa_title = "#FFFFFF"
sa_content = "#4A7D95"


#####################
# phrases 
#####################
ph_title = "yellow"
ph_item = "#FFFFFF"


#####################
# synonyms 
#####################
syn_title = "yellow"
syn_item = "#0074CC"
syn_em = "yellow"
syn_label = "#0F3850"


#####################
# examples on the web 
#####################
eg_title = "yellow"
eg_sentence = "#757575"
eg_word = "yellow"


#####################
# related phrases 
#####################
rph_title = "yellow"
rph_item = "#0074CC"


#####################
# nearby entries 
#####################
nearby_title = "yellow"
nearby_em = "yellow"
nearby_word = "#757575"
nearby_item = "#0074CC"


#####################
# dict name
#####################
dict_name = "#757575"
